# Code of Conduct

## Our Pledge

In the interest of fostering an open and innovative environment, we pledge to make participation in our project and community a harassment-free experience for everyone.

## Our Standards

Examples of behavior that contributes to creating a positive environment include:
- Using welcoming and inclusive language
- Encouraging collaboration on AI-driven solutions and respecting differing viewpoints

## Our Responsibilities

Project maintainers are responsible for clarifying the standards of acceptable behavior and are expected to take appropriate and fair corrective action in response to any instances of unacceptable behavior.

## Scope

This Code of Conduct applies within all project spaces and in public spaces when an individual is representing the project or its community.
